## Hydra-genetics modules
Listed are all modules currently available in the hydra-genetics framework. Links are provided to module specific documentation
covering all included softwares as well as links to respective github repositories.  

| Documentation | github |
| ----------------------------------- | ------ |
| [alignment](https://hydra-genetics-alignment.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/alignment](https://github.com/hydra-genetics/alignment) |
| [annotation](https://hydra-genetics-annotation.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/annotation](https://github.com/hydra-genetics/annotation) |
| [biomarker](https://hydra-genetics-biomarker.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/biomarker](https://github.com/hydra-genetics/biomarker) |
| [cnv_sv](https://hydra-genetics-cnv-sv.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/cnv_sv](https://github.com/hydra-genetics/cnv_sv) |
| [compression](https://hydra-genetics-compression.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/compression](https://github.com/hydra-genetics/compression) |
| [docker](https://hydra-genetics-docker.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/docker](https://github.com/hydra-genetics/docker) |
| [filtering](https://hydra-genetics-filtering.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/filtering](https://github.com/hydra-genetics/filtering) |
| [fusions](https://hydra-genetics-fusions.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/fusions](https://github.com/hydra-genetics/fusions) |
| [misc](https://hydra-genetics-misc.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/misc](https://github.com/hydra-genetics/misc) |
| [mitochondrial](https://hydra-genetics-mitochondrial.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/mitochondrial](https://github.com/hydra-genetics/mitochondrial) |
| [snv_indels](https://hydra-genetics-snv-indels.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/snv_indels](https://github.com/hydra-genetics/snv_indels) |
| [parabricks](https://hydra-genetics-parabricks.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/parabricks](https://github.com/hydra-genetics/parabricks) |
| [prealignment](https://hydra-genetics-prealignment.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/prealignment](https://github.com/hydra-genetics/prealignment) |
| [profiles](https://hydra-genetics-profiles.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/profiles](https://github.com/hydra-genetics/profiles) |
| [qc](https://hydra-genetics-qc.readthedocs.io/en/latest/) | [https://github.com/hydra-genetics/qc](https://github.com/hydra-genetics/qc) |

## Create new modules
Modules are created the same way as new [pipelines](create.md).
